@@ -7,10 +7,10 @@ from six.moves.urllib.parse import urlparse
 def region_from_glacier_url(url):
     domain = urlparse(url).netloc
 
-    if '.' in domain:
+    if "." in domain:
         return domain.split(".")[1]
     else:
-        return 'us-east-1'
+        return "us-east-1"
 
 
 def vault_from_glacier_url(full_url):
@@ -18,4 +18,6 @@ def vault_from_glacier_url(full_url):
 
 
 def get_job_id():
-    return ''.join(random.choice(string.ascii_uppercase + string.digits) for _ in range(92))
+    return "".join(
+        random.choice(string.ascii_uppercase + string.digits) for _ in range(92)
+    )
