@@ -1,10 +1,7 @@
 from moto.core import BaseBackend
 import boto.logs
 from moto.core.utils import unix_time_millis
-from .exceptions import (
-    ResourceNotFoundException,
-    ResourceAlreadyExistsException
-)
+from .exceptions import ResourceNotFoundException, ResourceAlreadyExistsException
 
 
 class LogEvent:
@@ -13,7 +10,7 @@ class LogEvent:
     def __init__(self, ingestion_time, log_event):
         self.ingestionTime = ingestion_time
         self.timestamp = log_event["timestamp"]
-        self.message = log_event['message']
+        self.message = log_event["message"]
         self.eventId = self.__class__._event_id
         self.__class__._event_id += 1
 
@@ -23,14 +20,14 @@ class LogEvent:
             "ingestionTime": self.ingestionTime,
             # "logStreamName":
             "message": self.message,
-            "timestamp": self.timestamp
+            "timestamp": self.timestamp,
         }
 
     def to_response_dict(self):
         return {
             "ingestionTime": self.ingestionTime,
             "message": self.message,
-            "timestamp": self.timestamp
+            "timestamp": self.timestamp,
         }
 
 
@@ -40,22 +37,32 @@ class LogStream:
     def __init__(self, region, log_group, name):
         self.region = region
         self.arn = "arn:aws:logs:{region}:{id}:log-group:{log_group}:log-stream:{log_stream}".format(
-            region=region, id=self.__class__._log_ids, log_group=log_group, log_stream=name)
-        self.creationTime = unix_time_millis()
+            region=region,
+            id=self.__class__._log_ids,
+            log_group=log_group,
+            log_stream=name,
+        )
+        self.creationTime = int(unix_time_millis())
         self.firstEventTimestamp = None
         self.lastEventTimestamp = None
         self.lastIngestionTime = None
         self.logStreamName = name
         self.storedBytes = 0
-        self.uploadSequenceToken = 0  # I'm  guessing this is token needed for sequenceToken by put_events
+        self.uploadSequenceToken = (
+            0  # I'm  guessing this is token needed for sequenceToken by put_events
+        )
         self.events = []
 
         self.__class__._log_ids += 1
 
     def _update(self):
         # events can be empty when stream is described soon after creation
-        self.firstEventTimestamp = min([x.timestamp for x in self.events]) if self.events else None
-        self.lastEventTimestamp = max([x.timestamp for x in self.events]) if self.events else None
+        self.firstEventTimestamp = (
+            min([x.timestamp for x in self.events]) if self.events else None
+        )
+        self.lastEventTimestamp = (
+            max([x.timestamp for x in self.events]) if self.events else None
+        )
 
     def to_describe_dict(self):
         # Compute start and end times
@@ -77,18 +84,31 @@ class LogStream:
             res.update(rest)
         return res
 
-    def put_log_events(self, log_group_name, log_stream_name, log_events, sequence_token):
+    def put_log_events(
+        self, log_group_name, log_stream_name, log_events, sequence_token
+    ):
         # TODO: ensure sequence_token
         # TODO: to be thread safe this would need a lock
-        self.lastIngestionTime = unix_time_millis()
+        self.lastIngestionTime = int(unix_time_millis())
         # TODO: make this match AWS if possible
         self.storedBytes += sum([len(log_event["message"]) for log_event in log_events])
-        self.events += [LogEvent(self.lastIngestionTime, log_event) for log_event in log_events]
+        self.events += [
+            LogEvent(self.lastIngestionTime, log_event) for log_event in log_events
+        ]
         self.uploadSequenceToken += 1
 
-        return '{:056d}'.format(self.uploadSequenceToken)
+        return "{:056d}".format(self.uploadSequenceToken)
 
-    def get_log_events(self, log_group_name, log_stream_name, start_time, end_time, limit, next_token, start_from_head):
+    def get_log_events(
+        self,
+        log_group_name,
+        log_stream_name,
+        start_time,
+        end_time,
+        limit,
+        next_token,
+        start_from_head,
+    ):
         def filter_func(event):
             if start_time and event.timestamp < start_time:
                 return False
@@ -98,19 +118,57 @@ class LogStream:
 
             return True
 
-        events = sorted(filter(filter_func, self.events), key=lambda event: event.timestamp, reverse=start_from_head)
-        back_token = next_token
-        if next_token is None:
-            next_token = 0
+        def get_paging_token_from_index(index, back=False):
+            if index is not None:
+                return "b/{:056d}".format(index) if back else "f/{:056d}".format(index)
+            return 0
 
-        events_page = [event.to_response_dict() for event in events[next_token: next_token + limit]]
-        next_token += limit
-        if next_token >= len(self.events):
-            next_token = None
+        def get_index_from_paging_token(token):
+            if token is not None:
+                return int(token[2:])
+            return 0
 
-        return events_page, back_token, next_token
+        events = sorted(
+            filter(filter_func, self.events),
+            key=lambda event: event.timestamp,
+            reverse=start_from_head,
+        )
+        next_index = get_index_from_paging_token(next_token)
+        back_index = next_index
+
+        events_page = [
+            event.to_response_dict()
+            for event in events[next_index : next_index + limit]
+        ]
+        if next_index + limit < len(self.events):
+            next_index += limit
+        else:
+            next_index = len(self.events)
+
+        back_index -= limit
+        if back_index <= 0:
+            back_index = 0
+
+        return (
+            events_page,
+            get_paging_token_from_index(back_index, True),
+            get_paging_token_from_index(next_index),
+        )
+
+    def filter_log_events(
+        self,
+        log_group_name,
+        log_stream_names,
+        start_time,
+        end_time,
+        limit,
+        next_token,
+        filter_pattern,
+        interleaved,
+    ):
+        if filter_pattern:
+            raise NotImplementedError("filter_pattern is not yet implemented")
 
-    def filter_log_events(self, log_group_name, log_stream_names, start_time, end_time, limit, next_token, filter_pattern, interleaved):
         def filter_func(event):
             if start_time and event.timestamp < start_time:
                 return False
@@ -121,9 +179,11 @@ class LogStream:
             return True
 
         events = []
-        for event in sorted(filter(filter_func, self.events), key=lambda x: x.timestamp):
+        for event in sorted(
+            filter(filter_func, self.events), key=lambda x: x.timestamp
+        ):
             event_obj = event.to_filter_dict()
-            event_obj['logStreamName'] = self.logStreamName
+            event_obj["logStreamName"] = self.logStreamName
             events.append(event_obj)
         return events
 
@@ -133,72 +193,140 @@ class LogGroup:
         self.name = name
         self.region = region
         self.arn = "arn:aws:logs:{region}:1:log-group:{log_group}".format(
-            region=region, log_group=name)
-        self.creationTime = unix_time_millis()
+            region=region, log_group=name
+        )
+        self.creationTime = int(unix_time_millis())
         self.tags = tags
         self.streams = dict()  # {name: LogStream}
-        self.retentionInDays = None  # AWS defaults to Never Expire for log group retention
+        self.retentionInDays = (
+            None  # AWS defaults to Never Expire for log group retention
+        )
 
     def create_log_stream(self, log_stream_name):
         if log_stream_name in self.streams:
             raise ResourceAlreadyExistsException()
-        self.streams[log_stream_name] = LogStream(self.region, self.name, log_stream_name)
+        self.streams[log_stream_name] = LogStream(
+            self.region, self.name, log_stream_name
+        )
 
     def delete_log_stream(self, log_stream_name):
         if log_stream_name not in self.streams:
             raise ResourceNotFoundException()
         del self.streams[log_stream_name]
 
-    def describe_log_streams(self, descending, limit, log_group_name, log_stream_name_prefix, next_token, order_by):
+    def describe_log_streams(
+        self,
+        descending,
+        limit,
+        log_group_name,
+        log_stream_name_prefix,
+        next_token,
+        order_by,
+    ):
         # responses only logStreamName, creationTime, arn, storedBytes when no events are stored.
 
-        log_streams = [(name, stream.to_describe_dict()) for name, stream in self.streams.items() if name.startswith(log_stream_name_prefix)]
+        log_streams = [
+            (name, stream.to_describe_dict())
+            for name, stream in self.streams.items()
+            if name.startswith(log_stream_name_prefix)
+        ]
 
         def sorter(item):
-            return item[0] if order_by == 'logStreamName' else item[1].get('lastEventTimestamp', 0)
+            return (
+                item[0]
+                if order_by == "logStreamName"
+                else item[1].get("lastEventTimestamp", 0)
+            )
 
         if next_token is None:
             next_token = 0
 
         log_streams = sorted(log_streams, key=sorter, reverse=descending)
         new_token = next_token + limit
-        log_streams_page = [x[1] for x in log_streams[next_token: new_token]]
+        log_streams_page = [x[1] for x in log_streams[next_token:new_token]]
         if new_token >= len(log_streams):
             new_token = None
 
         return log_streams_page, new_token
 
-    def put_log_events(self, log_group_name, log_stream_name, log_events, sequence_token):
+    def put_log_events(
+        self, log_group_name, log_stream_name, log_events, sequence_token
+    ):
         if log_stream_name not in self.streams:
             raise ResourceNotFoundException()
         stream = self.streams[log_stream_name]
-        return stream.put_log_events(log_group_name, log_stream_name, log_events, sequence_token)
+        return stream.put_log_events(
+            log_group_name, log_stream_name, log_events, sequence_token
+        )
 
-    def get_log_events(self, log_group_name, log_stream_name, start_time, end_time, limit, next_token, start_from_head):
+    def get_log_events(
+        self,
+        log_group_name,
+        log_stream_name,
+        start_time,
+        end_time,
+        limit,
+        next_token,
+        start_from_head,
+    ):
         if log_stream_name not in self.streams:
             raise ResourceNotFoundException()
         stream = self.streams[log_stream_name]
-        return stream.get_log_events(log_group_name, log_stream_name, start_time, end_time, limit, next_token, start_from_head)
+        return stream.get_log_events(
+            log_group_name,
+            log_stream_name,
+            start_time,
+            end_time,
+            limit,
+            next_token,
+            start_from_head,
+        )
 
-    def filter_log_events(self, log_group_name, log_stream_names, start_time, end_time, limit, next_token, filter_pattern, interleaved):
-        streams = [stream for name, stream in self.streams.items() if not log_stream_names or name in log_stream_names]
+    def filter_log_events(
+        self,
+        log_group_name,
+        log_stream_names,
+        start_time,
+        end_time,
+        limit,
+        next_token,
+        filter_pattern,
+        interleaved,
+    ):
+        streams = [
+            stream
+            for name, stream in self.streams.items()
+            if not log_stream_names or name in log_stream_names
+        ]
 
         events = []
         for stream in streams:
-            events += stream.filter_log_events(log_group_name, log_stream_names, start_time, end_time, limit, next_token, filter_pattern, interleaved)
+            events += stream.filter_log_events(
+                log_group_name,
+                log_stream_names,
+                start_time,
+                end_time,
+                limit,
+                next_token,
+                filter_pattern,
+                interleaved,
+            )
 
         if interleaved:
-            events = sorted(events, key=lambda event: event['timestamp'])
+            events = sorted(events, key=lambda event: event["timestamp"])
 
         if next_token is None:
             next_token = 0
 
-        events_page = events[next_token: next_token + limit]
+        events_page = events[next_token : next_token + limit]
         next_token += limit
         if next_token >= len(events):
             next_token = None
 
-        searched_streams = [{"logStreamName": stream.logStreamName, "searchedCompletely": True} for stream in streams]
+        searched_streams = [
+            {"logStreamName": stream.logStreamName, "searchedCompletely": True}
+            for stream in streams
+        ]
         return events_page, next_token, searched_streams
 
     def to_describe_dict(self):
@@ -217,6 +345,21 @@ class LogGroup:
     def set_retention_policy(self, retention_in_days):
         self.retentionInDays = retention_in_days
 
+    def list_tags(self):
+        return self.tags if self.tags else {}
+
+    def tag(self, tags):
+        if self.tags:
+            self.tags.update(tags)
+        else:
+            self.tags = tags
+
+    def untag(self, tags_to_remove):
+        if self.tags:
+            self.tags = {
+                k: v for (k, v) in self.tags.items() if k not in tags_to_remove
+            }
+
 
 class LogsBackend(BaseBackend):
     def __init__(self, region_name):
@@ -245,13 +388,17 @@ class LogsBackend(BaseBackend):
 
     def describe_log_groups(self, limit, log_group_name_prefix, next_token):
         if log_group_name_prefix is None:
-            log_group_name_prefix = ''
+            log_group_name_prefix = ""
         if next_token is None:
             next_token = 0
 
-        groups = [group.to_describe_dict() for name, group in self.groups.items() if name.startswith(log_group_name_prefix)]
-        groups = sorted(groups, key=lambda x: x['creationTime'], reverse=True)
-        groups_page = groups[next_token:next_token + limit]
+        groups = [
+            group.to_describe_dict()
+            for name, group in self.groups.items()
+            if name.startswith(log_group_name_prefix)
+        ]
+        groups = sorted(groups, key=lambda x: x["creationTime"], reverse=True)
+        groups_page = groups[next_token : next_token + limit]
 
         next_token += limit
         if next_token >= len(groups):
@@ -271,30 +418,85 @@ class LogsBackend(BaseBackend):
         log_group = self.groups[log_group_name]
         return log_group.delete_log_stream(log_stream_name)
 
-    def describe_log_streams(self, descending, limit, log_group_name, log_stream_name_prefix, next_token, order_by):
+    def describe_log_streams(
+        self,
+        descending,
+        limit,
+        log_group_name,
+        log_stream_name_prefix,
+        next_token,
+        order_by,
+    ):
         if log_group_name not in self.groups:
             raise ResourceNotFoundException()
         log_group = self.groups[log_group_name]
-        return log_group.describe_log_streams(descending, limit, log_group_name, log_stream_name_prefix, next_token, order_by)
+        return log_group.describe_log_streams(
+            descending,
+            limit,
+            log_group_name,
+            log_stream_name_prefix,
+            next_token,
+            order_by,
+        )
 
-    def put_log_events(self, log_group_name, log_stream_name, log_events, sequence_token):
+    def put_log_events(
+        self, log_group_name, log_stream_name, log_events, sequence_token
+    ):
         # TODO: add support for sequence_tokens
         if log_group_name not in self.groups:
             raise ResourceNotFoundException()
         log_group = self.groups[log_group_name]
-        return log_group.put_log_events(log_group_name, log_stream_name, log_events, sequence_token)
+        return log_group.put_log_events(
+            log_group_name, log_stream_name, log_events, sequence_token
+        )
 
-    def get_log_events(self, log_group_name, log_stream_name, start_time, end_time, limit, next_token, start_from_head):
+    def get_log_events(
+        self,
+        log_group_name,
+        log_stream_name,
+        start_time,
+        end_time,
+        limit,
+        next_token,
+        start_from_head,
+    ):
         if log_group_name not in self.groups:
             raise ResourceNotFoundException()
         log_group = self.groups[log_group_name]
-        return log_group.get_log_events(log_group_name, log_stream_name, start_time, end_time, limit, next_token, start_from_head)
+        return log_group.get_log_events(
+            log_group_name,
+            log_stream_name,
+            start_time,
+            end_time,
+            limit,
+            next_token,
+            start_from_head,
+        )
 
-    def filter_log_events(self, log_group_name, log_stream_names, start_time, end_time, limit, next_token, filter_pattern, interleaved):
+    def filter_log_events(
+        self,
+        log_group_name,
+        log_stream_names,
+        start_time,
+        end_time,
+        limit,
+        next_token,
+        filter_pattern,
+        interleaved,
+    ):
         if log_group_name not in self.groups:
             raise ResourceNotFoundException()
         log_group = self.groups[log_group_name]
-        return log_group.filter_log_events(log_group_name, log_stream_names, start_time, end_time, limit, next_token, filter_pattern, interleaved)
+        return log_group.filter_log_events(
+            log_group_name,
+            log_stream_names,
+            start_time,
+            end_time,
+            limit,
+            next_token,
+            filter_pattern,
+            interleaved,
+        )
 
     def put_retention_policy(self, log_group_name, retention_in_days):
         if log_group_name not in self.groups:
@@ -308,5 +510,25 @@ class LogsBackend(BaseBackend):
         log_group = self.groups[log_group_name]
         return log_group.set_retention_policy(None)
 
+    def list_tags_log_group(self, log_group_name):
+        if log_group_name not in self.groups:
+            raise ResourceNotFoundException()
+        log_group = self.groups[log_group_name]
+        return log_group.list_tags()
 
-logs_backends = {region.name: LogsBackend(region.name) for region in boto.logs.regions()}
+    def tag_log_group(self, log_group_name, tags):
+        if log_group_name not in self.groups:
+            raise ResourceNotFoundException()
+        log_group = self.groups[log_group_name]
+        log_group.tag(tags)
+
+    def untag_log_group(self, log_group_name, tags):
+        if log_group_name not in self.groups:
+            raise ResourceNotFoundException()
+        log_group = self.groups[log_group_name]
+        log_group.untag(tags)
+
+
+logs_backends = {
+    region.name: LogsBackend(region.name) for region in boto.logs.regions()
+}
