@@ -40,7 +40,6 @@ class SESFeedback(BaseModel):
 
 
 class Message(BaseModel):
-
     def __init__(self, message_id, source, subject, body, destinations):
         self.id = message_id
         self.source = source
@@ -49,8 +48,16 @@ class Message(BaseModel):
         self.destinations = destinations
 
 
-class RawMessage(BaseModel):
+class TemplateMessage(BaseModel):
+    def __init__(self, message_id, source, template, template_data, destinations):
+        self.id = message_id
+        self.source = source
+        self.template = template
+        self.template_data = template_data
+        self.destinations = destinations
 
+
+class RawMessage(BaseModel):
     def __init__(self, message_id, source, destinations, raw_data):
         self.id = message_id
         self.source = source
@@ -59,7 +66,6 @@ class RawMessage(BaseModel):
 
 
 class SESQuota(BaseModel):
-
     def __init__(self, sent):
         self.sent = sent
 
@@ -69,7 +75,6 @@ class SESQuota(BaseModel):
 
 
 class SESBackend(BaseBackend):
-
     def __init__(self):
         self.addresses = []
         self.email_addresses = []
@@ -82,7 +87,7 @@ class SESBackend(BaseBackend):
         _, address = parseaddr(source)
         if address in self.addresses:
             return True
-        user, host = address.split('@', 1)
+        user, host = address.split("@", 1)
         return host in self.domains
 
     def verify_email_identity(self, address):
@@ -101,7 +106,7 @@ class SESBackend(BaseBackend):
         return self.email_addresses
 
     def delete_identity(self, identity):
-        if '@' in identity:
+        if "@" in identity:
             self.addresses.remove(identity)
         else:
             self.domains.remove(identity)
@@ -109,11 +114,9 @@ class SESBackend(BaseBackend):
     def send_email(self, source, subject, body, destinations, region):
         recipient_count = sum(map(len, destinations.values()))
         if recipient_count > RECIPIENT_LIMIT:
-            raise MessageRejectedError('Too many recipients.')
+            raise MessageRejectedError("Too many recipients.")
         if not self._is_verified_address(source):
-            raise MessageRejectedError(
-                "Email address not verified %s" % source
-            )
+            raise MessageRejectedError("Email address not verified %s" % source)
 
         self.__process_sns_feedback__(source, destinations, region)
 
@@ -123,10 +126,33 @@ class SESBackend(BaseBackend):
         self.sent_message_count += recipient_count
         return message
 
+    def send_templated_email(
+        self, source, template, template_data, destinations, region
+    ):
+        recipient_count = sum(map(len, destinations.values()))
+        if recipient_count > RECIPIENT_LIMIT:
+            raise MessageRejectedError("Too many recipients.")
+        if not self._is_verified_address(source):
+            raise MessageRejectedError("Email address not verified %s" % source)
+
+        self.__process_sns_feedback__(source, destinations, region)
+
+        message_id = get_random_message_id()
+        message = TemplateMessage(
+            message_id, source, template, template_data, destinations
+        )
+        self.sent_messages.append(message)
+        self.sent_message_count += recipient_count
+        return message
+
     def __type_of_message__(self, destinations):
-        """Checks the destination for any special address that could indicate delivery, complaint or bounce
-        like in SES simualtor"""
-        alladdress = destinations.get("ToAddresses", []) + destinations.get("CcAddresses", []) + destinations.get("BccAddresses", [])
+        """Checks the destination for any special address that could indicate delivery,
+        complaint or bounce like in SES simualtor"""
+        alladdress = (
+            destinations.get("ToAddresses", [])
+            + destinations.get("CcAddresses", [])
+            + destinations.get("BccAddresses", [])
+        )
         for addr in alladdress:
             if SESFeedback.SUCCESS_ADDR in addr:
                 return SESFeedback.DELIVERY
@@ -159,30 +185,29 @@ class SESBackend(BaseBackend):
             _, source_email_address = parseaddr(source)
             if source_email_address not in self.addresses:
                 raise MessageRejectedError(
-                    "Did not have authority to send from email %s" % source_email_address
+                    "Did not have authority to send from email %s"
+                    % source_email_address
                 )
 
         recipient_count = len(destinations)
         message = email.message_from_string(raw_data)
         if source is None:
-            if message['from'] is None:
-                raise MessageRejectedError(
-                    "Source not specified"
-                )
+            if message["from"] is None:
+                raise MessageRejectedError("Source not specified")
 
-            _, source_email_address = parseaddr(message['from'])
+            _, source_email_address = parseaddr(message["from"])
             if source_email_address not in self.addresses:
                 raise MessageRejectedError(
-                    "Did not have authority to send from email %s" % source_email_address
+                    "Did not have authority to send from email %s"
+                    % source_email_address
                 )
 
-        for header in 'TO', 'CC', 'BCC':
+        for header in "TO", "CC", "BCC":
             recipient_count += sum(
-                d.strip() and 1 or 0
-                for d in message.get(header, '').split(',')
+                d.strip() and 1 or 0 for d in message.get(header, "").split(",")
             )
         if recipient_count > RECIPIENT_LIMIT:
-            raise MessageRejectedError('Too many recipients.')
+            raise MessageRejectedError("Too many recipients.")
 
         self.__process_sns_feedback__(source, destinations, region)
 
